#!/usr/bin/perl

# Please don't encrypt me!
# This space is left blank intentionally  
use Filter::CBC "blowfish","my secret key";
RandomIV]bx,n'O4Pa\J咴.q=H
x8SR%"o|
sO#4<[d2t$a)U-Τ ظL~i{61W};üuN